@@ -1,14 +1,15 @@
-import io
 import re
-from dataclasses import dataclass
 from typing import TextIO
 
-from cythonbuilder.services import logger
+# from .logs import logger
+
 
 class LineConverter:
 
     in_class_body:bool=False
     in_func_body:bool=False
+    in_enum_body:bool=False
+    in_name_main_body:bool=False
 
     def __init__(self, line:str, file_spaces_for_one_tab:int=4):
         self.pyx_line = line
@@ -46,9 +47,21 @@ class LineConverter:
         """ """
         return self.pyx_line[-1] == ":" and "class " in self.pyx_line
     @property
+    def is_name_main_def(self) -> bool:
+        """ """
+        # Clean quotes off
+        pyline = '"'.join(self.pyx_line.split("'"))
+        pyline = ''.join(pyline.split(" "))
+        return '__name__=="__main__"' in pyline
+    @property
+    def is_enum_def(self) -> bool:
+        return self.pyx_line[-1] == ':' and 'def enum' in self.pyx_line
+    @property
     def is_func_def(self) -> bool:
         """ Is C or PY function """
         line = self.pyx_line.strip(' ')
+        if (len(line) == 0):
+            return False
         word_array = line.split()
         endswith_colon = line[-1] == ':'
         contains_def = len(set(word_array).intersection({'cdef', 'def', 'cpdef'})) > 0
@@ -67,6 +80,8 @@ class LineConverter:
     @property
     def is_property(self) -> bool:
         line = self.pyx_line.strip()
+        if (len(line) == 0):
+            return False
         is_property = line[0] == '@'
         is_not_cython_property = '@cython.' not in line
         return all([is_property, is_not_cython_property])
@@ -99,7 +114,7 @@ class LineConverter:
                 py_line = f"{py_line.split('->')[0].strip()}:"
 
             array_between_brackets = re.findall('\(.*?\)', py_line)
-            logger.error(py_line)
+
             for brackets in array_between_brackets:
                 # Replace C return type to -> returntype
                 func_part_one_old = py_line.replace(f"{brackets}:", "")
@@ -147,7 +162,16 @@ class LineConverter:
             py_line = py_line + f"\n{self.file_spaces_for_one_tab * (self.indent_tabs + 1) * ' '}..."
         # return indentation * spaces_for_one_tab * ' ' + line
 
+        if (self.is_enum_def):
+            enum_name = self.pyx_line.split()[-1].replace(":", "")
+            py_line = f"class {enum_name}(Enum):"
+        if (self.in_enum_body):
+            py_line = self.pyx_line
+        if (self.is_name_main_def or self.in_name_main_body):
+            # py_line = "   "
+            return None
         # add original indentation back
+
         py_line = f"{self.file_spaces_for_one_tab * self.indent_tabs * ' '}" + py_line
 
         return py_line
@@ -194,6 +218,7 @@ def pyx_to_pyi(open_pyx:TextIO) -> [str]:
     all_indentations = [get_line_indentation_spacecount(line=l) for l in pyx_lines]
     all_indentations = [i for i in all_indentations if (i > 0)]
     spaces_for_one_tab = min(all_indentations)
+
     # Extra check: test wheter all are divisible by the space_for_one_tab
     for indent in all_indentations:
         if (indent % spaces_for_one_tab != 0):
@@ -203,6 +228,7 @@ def pyx_to_pyi(open_pyx:TextIO) -> [str]:
     # 5. Convert lines to py
     py_lines:[str] = []
     prev_line:LineConverter = None
+    contains_enum:bool = False
     for line_idx in range(len(pyx_lines)):
         pyxline = pyx_lines[line_idx]
 
@@ -215,30 +241,44 @@ def pyx_to_pyi(open_pyx:TextIO) -> [str]:
             elif (prev_line.in_class_body and not ld.is_class_def):
                 ld.in_class_body = True
 
+            # if __name__ == "__main__"
+            if (prev_line.is_name_main_def):
+                ld.in_name_main_body = True
+            elif (prev_line.in_name_main_body):
+                ld.in_name_main_body = True
+
             # Functions
             if (prev_line.is_func_def):
                 ld.in_func_body = True
-            elif (prev_line.in_func_body and (not ld.is_class_def and not ld.is_func_def)):
+            elif (prev_line.in_func_body and (not any([ld.is_class_def, ld.is_func_def, ld.is_enum_def]))):
                 ld.in_func_body = True
 
+            # Enums
+            if (prev_line.is_enum_def):
+                ld.in_enum_body= True
+                contains_enum = True
+            elif (prev_line.in_enum_body and (not any([ld.is_class_def, ld.is_func_def, ld.is_enum_def]))):
+                ld.in_enum_body = True
+
             # if current line defines anything
             if (ld.is_define_line):
                 ld.in_func_body = False
                 ld.in_class_body = False
+                ld.in_enum_body = False
 
-            # kep define lines an any lines that are in a class_body
-            if (not ld.in_class_body and not ld.is_define_line):
-                # logger.error(msg=f"{prev_line.indent_tabs},{ld.indent_tabs} - {l_is_class}{l_is_func}-{'C' if ld.in_class_body else 'X'}{'F' if ld.in_func_body else 'X'}, {ld.is_property} {pyxline}")
+            # kep define lines an any lines that are in a class_body or enum_body
+            if (not any([ld.in_class_body, ld.in_enum_body, ld.is_define_line])):
                 continue
-            # else:
-            # logger.debug(msg=f"{prev_line.indent_tabs},{ld.indent_tabs} - {l_is_class}{l_is_func}-{'C' if ld.in_class_body else 'X'}{'F' if ld.in_func_body else 'X'}, {ld.is_property} {pyxline}")
-
-            # logger.warning(msg=f"{ld.pyx_line}")
-            # logger.debug(msg=f"{ld.py_line}")
-
+        # if (any([ld.is_name_main_def, ld.in_name_main_body])):
+        #     ld.py_line = None
 
         prev_line = ld
-        py_lines.append(ld.py_line)
+        if (ld.py_line not in ['   ', None]):
+            py_lines.append(ld.py_line)
+
+    # 6. Add additional imports
+    if contains_enum:
+        py_lines.insert(0, "from enum import Enum\n")
 
     # 6. return
     return [f"{line}\n" for line in py_lines]
@@ -251,15 +291,12 @@ def pyx_to_pyi(open_pyx:TextIO) -> [str]:
 
 def get_line_indentation_spacecount(line: str) -> int:
     """ How many spaces is the provided line indented? """
-    spaces: int = 0
-    if (len(line) > 0):
-        if (line[0] == ' '):
-            for letter_idx in range(len(line)):
-                if (line[letter_idx + 1] != ' '):
-                    spaces = letter_idx + 1
-                    break
-    return spaces
-def get_line_indentation(line: str, file_spaces_for_one_tab:int) -> int:
-    """ How many spaces is the provided line indented? """
-    spaces = get_line_indentation_spacecount(line=line)
-    return int(spaces / file_spaces_for_one_tab)
\ No newline at end of file
+    num_spaces:int = 0
+
+    for char in line:
+        if char == ' ':
+            num_spaces += 1
+        else:
+            break
+
+    return num_spaces
\ No newline at end of file
